.. testsetup:: *

   from pwnlib.util.proc import *
   from pwnlib.tubes.process import process
   import os, sys


:mod:`pwnlib.util.proc` --- Working with ``/proc/``
===================================================

.. automodule:: pwnlib.util.proc
   :members:
